How‑to guides
=============

How‑to guides provide short recipes for solving a specific problem with
MicroPie.  They assume that you already know the basics covered in
the tutorials.  Each guide focuses on performing a single task.  See
the :doc:`tutorials <../tutorial/index>` for a more gentle
introduction.

.. toctree::
   :maxdepth: 1
   :caption: Guides

   sessions
   middleware
   templates
   streaming
   static_files
   socketio
   testing
